summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorWilliam Pitcock <nenolod@dereferenced.org>2011-03-17 22:13:45 -0500
committerWilliam Pitcock <nenolod@dereferenced.org>2011-03-17 22:13:45 -0500
commitb4bd23a34506acce8841423c4ed191c30cb8720a (patch)
tree6e08629efb74f51aca6d81526c4203452002c563
parent4c0d21a3246cf676872911d7839548414f88a150 (diff)
downloadaports-b4bd23a34506acce8841423c4ed191c30cb8720a.tar.bz2
aports-b4bd23a34506acce8841423c4ed191c30cb8720a.tar.xz
main/firefox: upgrade to 4.0_rc1
-rw-r--r--main/firefox/APKBUILD24
-rw-r--r--main/firefox/firefox-defaults.patch14
-rw-r--r--main/firefox/firefox-version.patch10
3 files changed, 22 insertions, 26 deletions
diff --git a/main/firefox/APKBUILD b/main/firefox/APKBUILD
index a4381be0e..aa3ff650c 100644
--- a/main/firefox/APKBUILD
+++ b/main/firefox/APKBUILD
@@ -1,8 +1,9 @@
# Contributor: William Pitcock <nenolod@dereferenced.org>
# Maintainer: William Pitcock <nenolod@dereferenced.org>
pkgname=firefox
-pkgver=3.6.15
-_xulver=1.9.2.15
+pkgver=4.0_rc1
+_pkgver=4.0rc1
+_xulver=2.0_rc1
pkgrel=3
pkgdesc="firefox web browser (unofficial branding)"
url="http://www.firefox.com"
@@ -34,21 +35,23 @@ makedepends="xulrunner-dev>=${_xulver}
python
zip
+ yasm
autoconf
automake
libtool"
install=""
subpackages=""
-source="http://releases.mozilla.org/pub/mozilla.org/${pkgname}/releases/${pkgver}/source/${pkgname}-${pkgver}.source.tar.bz2
+source="http://releases.mozilla.org/pub/mozilla.org/${pkgname}/releases/${pkgver}/source/${pkgname}-${_pkgver}.source.tar.bz2
mozconfig
- firefox-agent.patch
+
firefox-defaults.patch
firefox-version.patch
+
firefox.desktop
firefox-safe.desktop"
-_xulrunner_version="${_xulver%.*}"
+_xulrunner_version="2.0"
_builddir="${srcdir}/mozilla-${_xulrunner_version}"
prepare() {
local i
@@ -77,19 +80,18 @@ build() {
package() {
cd "$_builddir"
- make -j1 DESTDIR="$pkgdir" install || return 1
+ make -j1 DESTDIR="$pkgdir" -f client.mk install || return 1
install -m755 -d ${pkgdir}/usr/share/applications
install -m755 -d ${pkgdir}/usr/share/pixmaps
- install -m644 ${srcdir}/mozilla-1.9.2/browser/branding/unofficial/default48.png ${pkgdir}/usr/share/pixmaps/firefox.png
+ install -m644 ${srcdir}/mozilla-2.0/browser/branding/unofficial/default48.png ${pkgdir}/usr/share/pixmaps/firefox.png
install -m644 ${srcdir}/firefox.desktop ${pkgdir}/usr/share/applications/firefox.desktop
install -m644 ${srcdir}/firefox-safe.desktop ${pkgdir}/usr/share/applications/firefox-safe.desktop
}
-md5sums="fcf8042948d91f1f3d9c33599b79cf35 firefox-3.6.15.source.tar.bz2
+md5sums="511828dcc226f38602c6c67bd192ef40 firefox-4.0rc1.source.tar.bz2
7938f0054456f3767d2427dff137ab34 mozconfig
-f437e94acff8f810991271ef4677d859 firefox-agent.patch
-1807651225b021e043154f8bba715a19 firefox-defaults.patch
-92c11c66dd69b03f214002fededd1fc8 firefox-version.patch
+475a0870730c88f48158a4d4ca9812d0 firefox-defaults.patch
+0e296aabf8c2b5fd5ef5b3a989bab03a firefox-version.patch
ba96924ece1d77453e462429037a2ce5 firefox.desktop
6f38a5899034b7786cb1f75ad42032b8 firefox-safe.desktop"
diff --git a/main/firefox/firefox-defaults.patch b/main/firefox/firefox-defaults.patch
index d3cdb473a..cce60cd5d 100644
--- a/main/firefox/firefox-defaults.patch
+++ b/main/firefox/firefox-defaults.patch
@@ -1,11 +1,3 @@
-diff -Nur mozilla-1.9.2.old//browser/branding/unofficial/locales/browserconfig.properties mozilla-1.9.2/browser/branding/unofficial/locales/browserconfig.properties
---- mozilla-1.9.2.old//browser/branding/unofficial/locales/browserconfig.properties 2010-04-14 01:21:35.000000000 +0300
-+++ mozilla-1.9.2/browser/branding/unofficial/locales/browserconfig.properties 2010-04-20 23:55:32.036959438 +0300
-@@ -1,3 +1,3 @@
- # Do NOT localize or otherwise change these values
--browser.startup.homepage=http://www.mozilla.org/projects/namoroka/
-+browser.startup.homepage=http://www.google.com/firefox
-
diff --git a/main/firefox/firefox-version.patch b/main/firefox/firefox-version.patch
index a7f3740c7..2b1aeb41d 100644
--- a/main/firefox/firefox-version.patch
+++ b/main/firefox/firefox-version.patch
@@ -1,11 +1,11 @@
---- mozilla-1.9.1/browser/installer/Makefile.in.ver 2009-07-18 13:32:35.000000000 +0200
-+++ mozilla-1.9.1/browser/installer/Makefile.in 2009-07-18 13:33:12.000000000 +0200
+--- mozilla-2.0.orig/browser/installer/Makefile.in 2009-07-18 13:32:35.000000000 +0200
++++ mozilla-2.0/browser/installer/Makefile.in 2009-07-18 13:33:12.000000000 +0200
@@ -43,6 +43,8 @@
include $(DEPTH)/config/autoconf.mk
+MOZ_APP_VERSION="3.6"
+
- NO_PKG_FILES = \
- $(MOZ_APP_NAME)-config \
- $(MOZ_APP_NAME)-bin.elf \
+ include $(topsrcdir)/config/rules.mk
+
+ MOZ_PKG_REMOVALS = $(srcdir)/removed-files.in
diff -Nur mozilla-1.9.2.old//browser/branding/unofficial/pref/firefox-branding.js mozilla-1.9.2/browser/branding/unofficial/pref/firefox-branding.js
--- mozilla-1.9.2.old//browser/branding/unofficial/pref/firefox-branding.js 2010-04-14 01:21:35.000000000 +0300
+++ mozilla-1.9.2/browser/branding/unofficial/pref/firefox-branding.js 2010-04-20 23:55:01.290102941 +0300
@@ -14,15 +6,17 @@ diff -Nur mozilla-1.9.2.old//browser/branding/unofficial/pref/firefox-branding.j
-pref("startup.homepage_welcome_url","http://www.mozilla.org/projects/%APP%/%VERSION%/firstrun/");
+pref("startup.homepage_override_url","http://www.mozilla.com/%APP%/%VERSION%/whatsnew/");
+pref("startup.homepage_welcome_url","http://www.mozilla.com/%APP%/%VERSION%/firstrun/");
+ pref("browser.panorama.welcome_url", "http://www.mozilla.com/firefox/panorama/");
// The time interval between checks for a new version (in seconds)
// nightly=8 hours, official=24 hours
- pref("app.update.interval", 28800);
@@ -14,7 +14,7 @@
pref("app.update.url.details", "http://www.mozilla.org/projects/%APP%/");
- // Release notes URL
+ // Release notes and vendor URLs
-pref("app.releaseNotesURL", "http://www.mozilla.org/projects/%APP%/%VERSION%/releasenotes/");
+-pref("app.vendorURL", "http://www.mozilla.org/projects/%APP%/");
+pref("app.releaseNotesURL", "http://www.mozilla.com/%APP%/%VERSION%/releasenotes/");
++pref("app.vendorURL", "http://www.mozilla.com/%APP%/");
// Search codes belong only in builds with official branding
pref("browser.search.param.yahoo-fr", "");